// Pain Points Data
let painPoints = [
  {
    id: 1,
    name: "Price Sensitivity",
    scripts: [
      {
        id: 1,
        title: "Value Proposition",
        content:
          "We understand how crucial budget considerations are for businesses. OptimizeONE provides a comprehensive suite of tools that deliver significant long-term ROI by reducing the need for multiple subscriptions. Our platform not only helps you manage costs effectively but also enhances productivity and efficiency, ultimately leading to greater profitability. By streamlining operations and providing insights through advanced analytics, OptimizeONE helps you focus on what truly matters for sustained growth. Our goal is to offer not just immediate cost savings, but continued value that scales with your business.",
        tone: "Professional",
        length: "Long",
        successRate: 85,
      },
    ],
    date: "2023-10-01",
  },
  {
    id: 2,
    name: "Disparate Systems Leading to Inefficiency",
    scripts: [
      {
        id: 2,
        title: "Unified Platform Script",
        content:
          "Many businesses face the challenge of managing several tools that do not communicate well with each other, leading to inefficiencies and operational silos. With OptimizeONE, you can consolidate your operations into a single unified platform where all necessary tools work seamlessly together. This integration not only saves time but also reduces the risk of data discrepancies and errors. By centralizing your operations, you empower your team to focus on engaging with clients and driving growth rather than managing technology. The intuitive interface and robust toolset mean shorter onboarding times and a quicker path to enhanced productivity.",
        tone: "Professional",
        length: "Long",
        successRate: 85,
      },
    ],
    date: "2023-10-02",
  },
  {
    id: 3,
    name: "Difficulty Engaging Audience Across Multiple Channels",
    scripts: [
      {
        id: 3,
        title: "Engagement Optimization Script",
        content:
          "Reaching your audience effectively requires a strategy that leverages multiple channels while maintaining a consistent message. OptimizeONE enables unified communication by integrating email, SMS, and major social media platforms such as Facebook and Instagram. This means all your customer interactions are consolidated into one place, ensuring that no message goes unheard and no lead slips through the cracks. Our advanced targeting options and automation tools allow you to engage your audience in personalized and meaningful ways, fostering deeper connections and driving higher conversion rates.",
        tone: "Conversational",
        length: "Long",
        successRate: 82,
      },
    ],
    date: "2023-10-03",
  },
  {
    id: 4,
    name: "High Cost of Operating Multiple Tools",
    scripts: [
      {
        id: 4,
        title: "Cost Efficiency Script",
        content:
          "The financial burden of subscribing to multiple services can be overwhelming, especially when costs stack up without proportional increases in productivity. OptimizeONE provides a cost-effective solution by offering all the necessary business tools under one subscription. This eliminates excessive overhead and simplifies budgeting and training requirements. With our platform, your team will benefit from a cohesive work environment, more reliable data, and better insights that can lead to smarter business decisions and strategies. In addition to lowering your overheads, you'll find a system that grows and adapts to your evolving needs.",
        tone: "Informative",
        length: "Long",
        successRate: 79,
      },
    ],
    date: "2023-10-04",
  },
  {
    id: 5,
    name: "Struggling to Build and Convert Leads",
    scripts: [
      {
        id: 5,
        title: "Lead Conversion Script",
        content:
          "Optimizing lead conversion is crucial for business growth, and that's exactly what OptimizeONE excels at. Our high-converting website and sales funnel builders allow you to create visually appealing and functionally robust pages that guide your potential customers through a journey that ends in conversion. With built-in analytics and A/B testing, you can fine-tune your strategies to understand what resonates with your audience and make data-driven decisions. By constantly refining your approach, you stay one step ahead of competitors and ensure that your prospects become loyal customers.",
        tone: "Convincing",
        length: "Long",
        successRate: 88,
      },
    ],
    date: "2023-10-05",
  },
  {
    id: 6,
    name: "Lack of Automation Hindering Productivity",
    scripts: [
      {
        id: 6,
        title: "Automation Efficiency Script",
        content:
          "Manual tasks can bog down your team, consuming time better spent on strategic initiatives. OptimizeONE’s robust automation capabilities free up your valuable resources by taking over repetitive tasks, such as follow-ups, notifications, and customer queries. Our automation solutions are designed to be intuitive, requiring minimal setup and offering maximum impact. By enabling automation, your team can maintain focus on innovative projects and strategic growth, rather than routine administrative work, ultimately boosting overall productivity and morale.",
        tone: "Persuasive",
        length: "Long",
        successRate: 84,
      },
    ],
    date: "2023-10-06",
  },
  {
    id: 7,
    name: "Limited Customer Support Availability",
    scripts: [
      {
        id: 7,
        title: "24/7 Support Script",
        content:
          "Providing round-the-clock customer support is essential for maintaining high levels of customer satisfaction and engagement. With OptimizeONE's AI Employee, you can efficiently handle customer interactions at any hour without the need for additional staffing. This AI-driven tool is capable of answering queries, processing transactions, and even qualifying leads automatically. Your customers will always have access to the assistance they need, improving their experience and perception of your brand. This continuity not only enhances customer loyalty but also frees up your team to tackle more complex customer service issues better suited for human intervention.",
        tone: "Reassuring",
        length: "Long",
        successRate: 87,
      },
    ],
    date: "2023-10-07",
  },
  {
    id: 8,
    name: "Inefficient Sales Conversion",
    scripts: [
      {
        id: 8,
        title: "Sales Funnel Optimization Script",
        content:
          "Transforming prospects into customers requires an effective sales funnel that guides them through their decision-making process. OptimizeONE provides sophisticated tools that help you craft personalized customer journeys, from the first interaction to the final purchase. Each stage of the funnel is optimized for engagement and conversion, utilizing data insights to enhance the user experience. Our customizable templates and intuitive user interface make it easy to implement changes quickly, ensuring that your sales process remains agile and responsive to shifting customer needs and market conditions.",
        tone: "Persuasive",
        length: "Long",
        successRate: 83,
      },
    ],
    date: "2023-10-08",
  },
  {
    id: 9,
    name: "Complex Payment Processes",
    scripts: [
      {
        id: 9,
        title: "Payment Simplification Script",
        content:
          "Simplifying your payment processes not only enhances customer satisfaction but also optimizes your cash flow. OptimizeONE integrates with multiple trusted payment providers, including Stripe and PayPal, to offer a seamless transaction experience. Customers can easily complete payments with minimal friction, and you can manage and track all transactions from a single dashboard. Our platform ensures that financial transactions are secure, fast, and efficient, allowing you to focus less on administrative tasks and more on growing your business.",
        tone: "Reassuring",
        length: "Long",
        successRate: 81,
      },
    ],
    date: "2023-10-09",
  },
  {
    id: 10,
    name: "Inconsistent Branding Across Platforms",
    scripts: [
      {
        id: 10,
        title: "Brand Consistency Script",
        content:
          "Maintaining a consistent brand image across different platforms is crucial for building trust and recognition among your audience. OptimizeONE offers Brand Boards, which help you manage and synchronize your branding efforts by ensuring uniformity in logos, colors, and styles across all communication channels. This consistency reinforces brand identity, creating a cohesive experience for your audience regardless of where they engage with your brand. Such continuity in messaging strengthens brand loyalty and sets you apart from competitors who may lack this critical focus.",
        tone: "Informative",
        length: "Long",
        successRate: 80,
      },
    ],
    date: "2023-10-10",
  },
  {
    id: 11,
    name: "Time-Consuming Customer Onboarding",
    scripts: [
      {
        id: 11,
        title: "Onboarding Streamline Script",
        content:
          "A seamless onboarding experience is crucial for setting the tone of your client relationships. OptimizeONE’s platform simplifies this process with automation tools that effortlessly guide your new clients through the initial setup, reducing the manual input required by your team. Clients receive personalized onboarding paths tailored to their needs, which sets a solid foundation for a prosperous relationship. Our platform ensures that your onboarding process is not only time-efficient but also thorough, boosting customer satisfaction right from the start.",
        tone: "Efficient",
        length: "Long",
        successRate: 86,
      },
    ],
    date: "2023-10-11",
  },
  {
    id: 12,
    name: "Limited Insight into Performance Metrics",
    scripts: [
      {
        id: 12,
        title: "Performance Insight Script",
        content:
          "Informed decision-making starts with comprehensive data insights. OptimizeONE’s dashboards deliver real-time analytics and reporting, allowing you to track key performance indicators and identify trends as they emerge. Customizable metrics let you focus on the data that matters most to your business, enhancing your ability to make strategic decisions swiftly and accurately. Our analytics tools enable you to measure the success of your operations and strategies, fostering an environment where continual improvement is supported by actionable insights.",
        tone: "Analytical",
        length: "Long",
        successRate: 82,
      },
    ],
    date: "2023-10-12",
  },
  {
    id: 13,
    name: "Difficulty Managing Team Schedules",
    scripts: [
      {
        id: 13,
        title: "Schedule Management Script",
        content:
          "Effective team collaboration hinges on clear communication and coordinated schedules. OptimizeONE offers comprehensive calendar and team management tools to streamline scheduling processes. Automated reminders and notifications prevent scheduling conflicts, while shared calendars offer visibility into team availability. This ensures that everyone is aligned, enhancing collaboration and improving project timelines. By automating scheduling logistics, your team can dedicate more time to strategic initiatives rather than administrative tasks.",
        tone: "Organized",
        length: "Long",
        successRate: 84,
      },
    ],
    date: "2023-10-13",
  },
  {
    id: 14,
    name: "Lack of Customer Feedback Integration",
    scripts: [
      {
        id: 14,
        title: "Feedback Integration Script",
        content:
          "Harnessing customer feedback is vital for evolving and adapting your services to meet market demands. OptimizeONE’s suite of online forms, quizzes, and surveys allow you to efficiently capture and analyze feedback, integrating insights directly into your strategic planning. This integration empowers you to respond swiftly to customer concerns and preferences, ensuring your offerings remain relevant and competitive. Encouraging and acting upon feedback demonstrates to customers that their opinions are valued, bolstering trust and loyalty.",
        tone: "Interactive",
        length: "Long",
        successRate: 80,
      },
    ],
    date: "2023-10-14",
  },
  {
    id: 15,
    name: "Manual Task Overload",
    scripts: [
      {
        id: 15,
        title: "Task Automation Script",
        content:
          "Repetitive tasks can drain productivity and morale. OptimizeONE’s workflow automations handle these mundane processes, freeing up your team to focus on activities that require creativity and critical thinking. Whether it’s automating communications, alerts, or approvals, our platform streamlines operations and minimizes manual interventions. With automated systems handling routine tasks, your team's overall efficiency and satisfaction increase—empowering them to contribute more effectively to achieving business goals.",
        tone: "Efficient",
        length: "Long",
        successRate: 89,
      },
    ],
    date: "2023-10-15",
  },
];

// DOM Elements
const painPointsList = document.getElementById("painPointsList");
const searchInput = document.getElementById("searchInput");
const searchButton = document.getElementById("searchButton");
const scriptModal = document.getElementById("scriptModal");
const scriptDetails = document.getElementById("scriptDetails");
const closeModal = document.querySelector(".close");

// Functions
function displayPainPoints(filteredPoints = painPoints) {
  painPointsList.innerHTML = filteredPoints
    .map(
      (point) => `
    <div class="pain-point" data-id="${point.id}">
      <h3>${point.name}</h3>
      <p>${point.scripts.length} script(s) available</p>
    </div>
  `,
    )
    .join("");
}

function showScriptDetails(pointId) {
  const point = painPoints.find((p) => p.id === pointId);
  if (point) {
    scriptDetails.innerHTML = point.scripts
      .map(
        (script) => `
      <div class="script">
        <h4>${script.title}</h4>
        <p>${script.content}</p>
        <div class="meta">
          <span>Tone: ${script.tone}</span>
          <span>Length: ${script.length}</span>
          <span>Success Rate: ${script.successRate}%</span>
        </div>
      </div>
    `,
      )
      .join("");
    scriptModal.style.display = "block";
  }
}

// Event Listeners
document.addEventListener("DOMContentLoaded", () => displayPainPoints());
painPointsList.addEventListener("click", (e) => {
  const point = e.target.closest(".pain-point");
  if (point) {
    const pointId = parseInt(point.dataset.id);
    showScriptDetails(pointId);
  }
});
closeModal.addEventListener("click", () => {
  scriptModal.style.display = "none";
});
window.addEventListener("click", (e) => {
  if (e.target === scriptModal) {
    scriptModal.style.display = "none";
  }
});
searchButton.addEventListener("click", () => {
  const searchTerm = searchInput.value.toLowerCase();
  const filteredPoints = painPoints.filter((point) =>
    point.name.toLowerCase().includes(searchTerm),
  );
  displayPainPoints(filteredPoints);
});
